Crate dbx_tools_databricks_auth

Crate dbx_tools_databricks_auth 

Structs

AccessToken
AuthClient
AuthOptions
DatabricksAuthOptions
Configuration shared by the generated Node and Python auth bindings.
DatabricksAuthStatus
FileStore
KeyringStore
MachineToMachineFlow
Databricks OAuth client-credentials flow for service principals.
MemoryStore
OAuthFlow
OAuthTemplate
Branding and content renderer for the browser OAuth callback.
OAuthTemplateContext
Values displayed by the browser OAuth callback.
PersistentAuth
Profile
ProfileOptions
StoreOptions
Token
UniFfiTraitVtableStorageAdapter

Enums

AuthKind
OAuth strategy selected from Databricks configuration.
DatabricksAuthError
Error
Storage
StoreBackend
TargetKind

Constants

DEFAULT_ACCOUNTS_HOST
DEFAULT_CLIENT_ID
DEFAULT_CONFIG_FILE

Traits

CredentialStore
StorageAdapter
StorageLock

Functions

create_persistent_auth
create_persistent_auth_with_storage
default_callback_image_src
Build the default callback logo as an embedded SVG data URI.
open_store
resolve_config_file
uniffi_dbx_tools_databricks_auth_fn_init_callback_vtable_storageadapter

Type Aliases

Result