Structs
- Access
Token - Auth
Client - Auth
Options - Databricks
Auth Options - Configuration shared by the generated Node and Python auth bindings.
- Databricks
Auth Status - File
Store - Keyring
Store - Machine
ToMachine Flow - Databricks OAuth client-credentials flow for service principals.
- Memory
Store - OAuth
Flow - OAuth
Template - Branding and content renderer for the browser OAuth callback.
- OAuth
Template Context - Values displayed by the browser OAuth callback.
- Persistent
Auth - Profile
- Profile
Options - Store
Options - Token
- UniFfi
Trait Vtable Storage Adapter
Enums
- Auth
Kind - OAuth strategy selected from Databricks configuration.
- Databricks
Auth Error - Error
- Storage
- Store
Backend - Target
Kind
Constants
Traits
Functions
- create_
persistent_ auth - create_
persistent_ auth_ with_ storage - default_
callback_ image_ src - Build the default callback logo as an embedded SVG data URI.
- open_
store - resolve_
config_ file - uniffi_
dbx_ tools_ databricks_ auth_ fn_ init_ callback_ vtable_ storageadapter